@@ -19,5 +19,8 @@ settings.configure(
     }
 )
 
+import django
+django.setup()
+
 from django.core import management
 management.call_command('test')
